@@ -5,7 +5,7 @@ class AjaxSelectConfig(AppConfig):
 
     """
     Django 1.7+ enables initializing installed applications
-    and autodiscovering modules
+    and autodiscovering modules.
 
     On startup, search for and import any modules called `lookups.py` in all installed apps.
     Your LookupClass subclass may register itself.
