@@ -10,5 +10,5 @@ admin.autodiscover()
 
 urlpatterns = [
     url(r'^ajax_lookups/', include(ajax_select_urls)),
-    url(r'^admin/', include(admin.site.urls)),
+    url(r'^admin/', admin.site.urls),
 ] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
